@@ -238,7 +238,9 @@ where
 
     let left_asof = left_asof.rechunk();
     let err = |_: PolarsError| {
-        PolarsError::ComputeError("Keys are not allowed to have null values in asof join.".into())
+        polars_err!(
+            ComputeError: "keys are not allowed to have null values in asof join"
+        )
     };
     let left_asof = left_asof.cont_slice().map_err(err)?;
 
@@ -649,8 +651,18 @@ impl DataFrame {
 
         check_asof_columns(&left_asof, &right_asof)?;
 
-        let mut left_by = self.select_physical(left_by)?;
-        let mut right_by = other.select_physical(right_by)?;
+        let mut left_by = self.select(left_by)?;
+        let mut right_by = other.select(right_by)?;
+        for (l, r) in left_by
+            .get_columns_mut()
+            .iter_mut()
+            .zip(right_by.get_columns_mut().iter_mut())
+        {
+            #[cfg(feature = "dtype-categorical")]
+            _check_categorical_src(l.dtype(), r.dtype())?;
+            *l = l.to_physical_repr().into_owned();
+            *r = r.to_physical_repr().into_owned();
+        }
 
         let left_by_s = left_by.get_columns()[0].to_physical_repr().into_owned();
         let right_by_s = right_by.get_columns()[0].to_physical_repr().into_owned();
