@@ -1,3 +1,5 @@
+use smartstring::alias::String as SmartString;
+
 use crate::prelude::*;
 use crate::series::IsSorted;
 use crate::utils::{concat_df_unchecked, slice_offsets, CustomIterTools, NoNull};
@@ -49,8 +51,10 @@ impl DataFrame {
         let n_rows_left = self.height() as IdxSize;
         let n_rows_right = other.height() as IdxSize;
         let Some(total_rows) = n_rows_left.checked_mul(n_rows_right) else {
-            return Err(PolarsError::ComputeError("Cross joins would produce more rows than fits into 2^32.\n\
-            Consider comping with polars-big-idx feature, or set 'streaming'.".into()))
+            polars_bail!(
+                ComputeError: "cross joins would produce more rows than fits into 2^32; \
+                consider comping with polars-big-idx feature, or set 'streaming'"
+            );
         };
         if n_rows_left == 0 || n_rows_right == 0 {
             return Ok((self.clear(), other.clear()));
@@ -96,7 +100,7 @@ impl DataFrame {
     pub fn _cross_join_with_names(
         &self,
         other: &DataFrame,
-        names: &[String],
+        names: &[SmartString],
     ) -> PolarsResult<DataFrame> {
         let (mut l_df, r_df) = self.cross_join_dfs(other, None, false)?;
         l_df.get_columns_mut().extend_from_slice(&r_df.columns);
