@@ -1,3 +1,5 @@
+use std::fmt::Write;
+
 use crate::prelude::*;
 
 fn any_values_to_primitive<T: PolarsNumericType>(avs: &[AnyValue]) -> ChunkedArray<T> {
@@ -7,16 +9,96 @@ fn any_values_to_primitive<T: PolarsNumericType>(avs: &[AnyValue]) -> ChunkedArr
 }
 
 fn any_values_to_utf8(avs: &[AnyValue]) -> Utf8Chunked {
-    avs.iter()
-        .map(|av| match av {
-            AnyValue::Utf8(s) => Some(*s),
-            AnyValue::Utf8Owned(s) => Some(&**s),
-            _ => None,
-        })
-        .collect_trusted()
+    let mut builder = Utf8ChunkedBuilder::new("", avs.len(), avs.len() * 10);
+
+    // amortize allocations
+    let mut owned = String::new();
+
+    for av in avs {
+        match av {
+            AnyValue::Utf8(s) => builder.append_value(s),
+            AnyValue::Utf8Owned(s) => builder.append_value(s),
+            AnyValue::Null => builder.append_null(),
+            AnyValue::Binary(_) | AnyValue::BinaryOwned(_) => builder.append_null(),
+            av => {
+                owned.clear();
+                write!(owned, "{av}").unwrap();
+                builder.append_value(&owned);
+            }
+        }
+    }
+    builder.finish()
+}
+
+#[cfg(feature = "dtype-decimal")]
+fn any_values_to_decimal(
+    avs: &[AnyValue],
+    precision: Option<usize>,
+    scale: Option<usize>, // if None, we're inferring the scale
+) -> PolarsResult<DecimalChunked> {
+    // two-pass approach, first we scan and record the scales, then convert (or not)
+    let mut scale_range: Option<(usize, usize)> = None;
+    for av in avs {
+        let s_av = if av.is_signed() || av.is_unsigned() {
+            0 // integers are treated as decimals with scale of zero
+        } else if let AnyValue::Decimal(_, scale) = av {
+            *scale
+        } else if matches!(av, AnyValue::Null) {
+            continue;
+        } else {
+            polars_bail!(
+                ComputeError: "unable to convert any-value of dtype {} to decimal", av.dtype(),
+            );
+        };
+        scale_range = match scale_range {
+            None => Some((s_av, s_av)),
+            Some((s_min, s_max)) => Some((s_min.min(s_av), s_max.max(s_av))),
+        };
+    }
+    let Some((s_min, s_max)) = scale_range else {
+        // empty array or all nulls, return a decimal array with given scale (or 0 if inferring)
+        return Ok(
+            Int128Chunked::full_null("", avs.len())
+                .into_decimal_unchecked(precision, scale.unwrap_or(0))
+        );
+    };
+    let scale = scale.unwrap_or(s_max);
+    if s_max > scale {
+        // scale is provided but is lower than actual
+        // TODO: do we want lossy conversions here or not?
+        polars_bail!(
+            ComputeError:
+            "unable to losslessly convert any-value of scale {s_max} to scale {}", scale,
+        );
+    } else if s_min == s_max && s_max == scale {
+        // no conversions needed; will potentially check values for precision though
+        any_values_to_primitive::<Int128Type>(avs).into_decimal(precision, scale)
+    } else {
+        // rescaling is needed
+        let mut builder = PrimitiveChunkedBuilder::<Int128Type>::new("", avs.len());
+        for av in avs {
+            let (v, s_av) = if av.is_signed() || av.is_unsigned() {
+                (
+                    av.try_extract::<i128>().unwrap_or_else(|_| unreachable!()),
+                    0,
+                )
+            } else if let AnyValue::Decimal(v, scale) = av {
+                (*v, *scale)
+            } else {
+                // it has to be a null because we've already checked it
+                builder.append_null();
+                continue;
+            };
+            let factor = 10_i128.pow((scale - s_av) as _); // this cast is safe
+            builder.append_value(v.checked_mul(factor).ok_or_else(|| {
+                polars_err!(ComputeError: "overflow while converting to decimal scale {}", scale)
+            })?);
+        }
+        // build the array and do a precision check if needed
+        builder.finish().into_decimal(precision, scale)
+    }
 }
 
-#[cfg(feature = "dtype-binary")]
 fn any_values_to_binary(avs: &[AnyValue]) -> BinaryChunked {
     avs.iter()
         .map(|av| match av {
@@ -95,7 +177,6 @@ impl Series {
             DataType::Float32 => any_values_to_primitive::<Float32Type>(av).into_series(),
             DataType::Float64 => any_values_to_primitive::<Float64Type>(av).into_series(),
             DataType::Utf8 => any_values_to_utf8(av).into_series(),
-            #[cfg(feature = "dtype-binary")]
             DataType::Binary => any_values_to_binary(av).into_series(),
             DataType::Boolean => any_values_to_bool(av).into_series(),
             #[cfg(feature = "dtype-date")]
@@ -114,6 +195,10 @@ impl Series {
             DataType::Duration(tu) => any_values_to_primitive::<Int64Type>(av)
                 .into_duration(*tu)
                 .into_series(),
+            #[cfg(feature = "dtype-decimal")]
+            DataType::Decimal(precision, scale) => {
+                any_values_to_decimal(av, *precision, *scale)?.into_series()
+            }
             DataType::List(inner) => any_values_to_list(av, inner).into_series(),
             #[cfg(feature = "dtype-struct")]
             DataType::Struct(dtype_fields) => {
@@ -174,7 +259,13 @@ impl Series {
                             _ => field_avs.push(AnyValue::Null),
                         }
                     }
-                    series_fields.push(Series::new(field.name(), &field_avs))
+                    // if the inferred dtype is null, we let auto inference work
+                    let s = if matches!(field.dtype, DataType::Null) {
+                        Series::new(field.name(), &field_avs)
+                    } else {
+                        Series::from_any_values_and_dtype(field.name(), &field_avs, &field.dtype)?
+                    };
+                    series_fields.push(s)
                 }
                 return Ok(StructChunked::new(name, &series_fields)
                     .unwrap()
@@ -195,25 +286,17 @@ impl Series {
                 }
                 return Ok(builder.to_series());
             }
-            DataType::Null => {
-                // TODO!
-                // use null dtype here and fix tests
-                Series::full_null(name, av.len(), &DataType::Int32)
-            }
+            DataType::Null => Series::full_null(name, av.len(), &DataType::Null),
             #[cfg(feature = "dtype-categorical")]
             DataType::Categorical(_) => {
                 let ca = if let Some(single_av) = av.first() {
                     match single_av {
                         AnyValue::Utf8(_) | AnyValue::Utf8Owned(_) => any_values_to_utf8(av),
-                        _ => {
-                            return Err(PolarsError::ComputeError(
-                                format!(
-                                    "categorical dtype with AnyValues of dtype: {} not supported",
-                                    single_av.dtype()
-                                )
-                                .into(),
-                            ))
-                        }
+                        _ => polars_bail!(
+                             ComputeError:
+                             "categorical dtype with any-values of dtype {} not supported",
+                             single_av.dtype()
+                        ),
                     }
                 } else {
                     Utf8Chunked::full("", "", 0)
@@ -227,12 +310,20 @@ impl Series {
         Ok(s)
     }
 
-    pub fn from_any_values(name: &str, av: &[AnyValue]) -> PolarsResult<Series> {
-        match av.iter().find(|av| !matches!(av, AnyValue::Null)) {
-            None => Ok(Series::full_null(name, av.len(), &DataType::Int32)),
-            Some(av_) => {
-                let dtype: DataType = av_.into();
-                Series::from_any_values_and_dtype(name, av, &dtype)
+    pub fn from_any_values(name: &str, avs: &[AnyValue]) -> PolarsResult<Series> {
+        match avs.iter().find(|av| !matches!(av, AnyValue::Null)) {
+            None => Ok(Series::full_null(name, avs.len(), &DataType::Int32)),
+            Some(av) => {
+                #[cfg(feature = "dtype-decimal")]
+                {
+                    if let AnyValue::Decimal(_, _) = av {
+                        let mut s = any_values_to_decimal(avs, None, None)?.into_series();
+                        s.rename(name);
+                        return Ok(s);
+                    }
+                }
+                let dtype: DataType = av.into();
+                Series::from_any_values_and_dtype(name, avs, &dtype)
             }
         }
     }
@@ -245,7 +336,6 @@ impl<'a> From<&AnyValue<'a>> for DataType {
             Null => DataType::Null,
             Boolean(_) => DataType::Boolean,
             Utf8(_) | Utf8Owned(_) => DataType::Utf8,
-            #[cfg(feature = "dtype-binary")]
             Binary(_) | BinaryOwned(_) => DataType::Binary,
             UInt32(_) => DataType::UInt32,
             UInt64(_) => DataType::UInt64,
@@ -284,6 +374,8 @@ impl<'a> From<&AnyValue<'a>> for DataType {
             Object(o) => DataType::Object(o.type_name()),
             #[cfg(feature = "object")]
             ObjectOwned(o) => DataType::Object(o.0.type_name()),
+            #[cfg(feature = "dtype-decimal")]
+            Decimal(_, scale) => DataType::Decimal(None, Some(*scale)),
         }
     }
 }
