@@ -17,21 +17,11 @@ pub enum IsSorted {
     Not,
 }
 
-macro_rules! invalid_operation {
-    ($s:expr) => {
-        Err(PolarsError::InvalidOperation(
-            format!(
-                "this operation is not implemented/valid for this dtype: {:?}",
-                $s._dtype()
-            )
-            .into(),
-        ))
-    };
-}
 macro_rules! invalid_operation_panic {
-    ($s:expr) => {
+    ($op:ident, $s:expr) => {
         panic!(
-            "this operation is not implemented/valid for this dtype: {:?}",
+            "`{}` operation not supported for dtype `{}`",
+            stringify!($op),
             $s._dtype()
         )
     };
@@ -65,7 +55,7 @@ pub(crate) mod private {
             _values_capacity: usize,
             _list_capacity: usize,
         ) -> Box<dyn ListBuilderTrait> {
-            invalid_operation_panic!(self)
+            invalid_operation_panic!(get_list_builder, self)
         }
 
         /// Get field (used in schema)
@@ -78,7 +68,7 @@ pub(crate) mod private {
         }
 
         fn explode_by_offsets(&self, _offsets: &[i64]) -> Series {
-            invalid_operation_panic!(self)
+            invalid_operation_panic!(explode_by_offsets, self)
         }
 
         /// Get an array with the cumulative max computed at every element
@@ -103,25 +93,25 @@ pub(crate) mod private {
             _idx_other: usize,
             _other: &Series,
         ) -> bool {
-            invalid_operation_panic!(self)
+            invalid_operation_panic!(equal_element, self)
         }
         #[allow(clippy::wrong_self_convention)]
         fn into_partial_eq_inner<'a>(&'a self) -> Box<dyn PartialEqInner + 'a> {
-            invalid_operation_panic!(self)
+            invalid_operation_panic!(into_partial_eq_inner, self)
         }
         #[allow(clippy::wrong_self_convention)]
         fn into_partial_ord_inner<'a>(&'a self) -> Box<dyn PartialOrdInner + 'a> {
-            invalid_operation_panic!(self)
+            invalid_operation_panic!(into_partial_ord_inner, self)
         }
         fn vec_hash(&self, _build_hasher: RandomState, _buf: &mut Vec<u64>) -> PolarsResult<()> {
-            invalid_operation!(self)
+            polars_bail!(opq = vec_hash, self._dtype());
         }
         fn vec_hash_combine(
             &self,
             _build_hasher: RandomState,
             _hashes: &mut [u64],
         ) -> PolarsResult<()> {
-            invalid_operation!(self)
+            polars_bail!(opq = vec_hash_combine, self._dtype());
         }
         unsafe fn agg_min(&self, groups: &GroupsProxy) -> Series {
             Series::full_null(self._field().name(), groups.len(), self._dtype())
@@ -149,39 +139,37 @@ pub(crate) mod private {
             _right_column: &Series,
             _opt_join_tuples: &[(Option<IdxSize>, Option<IdxSize>)],
         ) -> Series {
-            invalid_operation_panic!(self)
+            invalid_operation_panic!(zip_outer_join_column, self)
         }
 
         fn subtract(&self, _rhs: &Series) -> PolarsResult<Series> {
-            invalid_operation_panic!(self)
+            invalid_operation_panic!(sub, self)
         }
         fn add_to(&self, _rhs: &Series) -> PolarsResult<Series> {
-            invalid_operation!(self)
+            invalid_operation_panic!(add, self)
         }
         fn multiply(&self, _rhs: &Series) -> PolarsResult<Series> {
-            invalid_operation_panic!(self)
+            invalid_operation_panic!(mul, self)
         }
         fn divide(&self, _rhs: &Series) -> PolarsResult<Series> {
-            invalid_operation_panic!(self)
+            invalid_operation_panic!(div, self)
         }
         fn remainder(&self, _rhs: &Series) -> PolarsResult<Series> {
-            invalid_operation!(self)
+            invalid_operation_panic!(rem, self)
         }
         fn group_tuples(&self, _multithreaded: bool, _sorted: bool) -> PolarsResult<GroupsProxy> {
-            invalid_operation!(self)
+            invalid_operation_panic!(group_tuples, self)
         }
         fn zip_with_same_type(
             &self,
             _mask: &BooleanChunked,
             _other: &Series,
         ) -> PolarsResult<Series> {
-            invalid_operation_panic!(self)
+            invalid_operation_panic!(zip_with_same_type, self)
         }
         #[cfg(feature = "sort_multiple")]
         fn arg_sort_multiple(&self, _by: &[Series], _descending: &[bool]) -> PolarsResult<IdxCa> {
-            Err(PolarsError::InvalidOperation(
-                "arg_sort_multiple is not implemented for this Series".into(),
-            ))
+            polars_bail!(opq = arg_sort_multiple, self._dtype());
         }
     }
 }
@@ -198,38 +186,20 @@ pub trait SeriesTrait:
     fn rename(&mut self, name: &str);
 
     fn bitand(&self, _other: &Series) -> PolarsResult<Series> {
-        Err(PolarsError::InvalidOperation(
-            format!(
-                "bitwise 'AND' operation not supported for dtype {:?}",
-                self.dtype()
-            )
-            .into(),
-        ))
+        polars_bail!(opq = bitand, self._dtype());
     }
 
     fn bitor(&self, _other: &Series) -> PolarsResult<Series> {
-        Err(PolarsError::InvalidOperation(
-            format!(
-                "bitwise 'OR' operation not supported for dtype {:?}",
-                self.dtype()
-            )
-            .into(),
-        ))
+        polars_bail!(opq = bitor, self._dtype());
     }
 
     fn bitxor(&self, _other: &Series) -> PolarsResult<Series> {
-        Err(PolarsError::InvalidOperation(
-            format!(
-                "bitwise 'XOR' operation not supported for dtype {:?}",
-                self.dtype()
-            )
-            .into(),
-        ))
+        polars_bail!(opq = bitxor, self._dtype());
     }
 
     /// Get the lengths of the underlying chunks
     fn chunk_lengths(&self) -> ChunkIdIter {
-        invalid_operation_panic!(self)
+        invalid_operation_panic!(chunk_lengths, self)
     }
     /// Name of series.
     fn name(&self) -> &str;
@@ -254,7 +224,7 @@ pub trait SeriesTrait:
 
     /// Shrink the capacity of this array to fit its length.
     fn shrink_to_fit(&mut self) {
-        panic!("shrink to fit not supported for dtype {:?}", self.dtype())
+        invalid_operation_panic!(shrink_to_fit, self);
     }
 
     /// Take `num_elements` from the top as a zero copy view.
@@ -314,7 +284,7 @@ pub trait SeriesTrait:
     /// todo! remove?
     #[cfg(feature = "take_opt_iter")]
     fn take_opt_iter(&self, _iter: &mut dyn TakeIteratorNulls) -> PolarsResult<Series> {
-        invalid_operation_panic!(self)
+        invalid_operation_panic!(take_opt_iter, self)
     }
 
     /// Take by index. This operation is clone.
@@ -382,17 +352,17 @@ pub trait SeriesTrait:
     /// Does not do any bounds checking
     #[cfg(feature = "private")]
     unsafe fn get_unchecked(&self, _index: usize) -> AnyValue {
-        invalid_operation_panic!(self)
+        invalid_operation_panic!(get_unchecked, self)
     }
 
     fn sort_with(&self, _options: SortOptions) -> Series {
-        invalid_operation_panic!(self)
+        invalid_operation_panic!(sort_with, self)
     }
 
     /// Retrieve the indexes needed for a sort.
     #[allow(unused)]
     fn arg_sort(&self, options: SortOptions) -> IdxCa {
-        invalid_operation_panic!(self)
+        invalid_operation_panic!(arg_sort, self)
     }
 
     /// Count the null values.
@@ -404,17 +374,17 @@ pub trait SeriesTrait:
 
     /// Get unique values in the Series.
     fn unique(&self) -> PolarsResult<Series> {
-        invalid_operation!(self)
+        polars_bail!(opq = unique, self._dtype());
     }
 
     /// Get unique values in the Series.
     fn n_unique(&self) -> PolarsResult<usize> {
-        invalid_operation_panic!(self)
+        invalid_operation_panic!(n_unique, self)
     }
 
     /// Get first indexes of unique values.
     fn arg_unique(&self) -> PolarsResult<IdxCa> {
-        invalid_operation_panic!(self)
+        invalid_operation_panic!(arg_unique, self)
     }
 
     /// Get a mask of the null values.
@@ -429,9 +399,7 @@ pub trait SeriesTrait:
     /// Rechunk and return a pointer to the start of the Series.
     /// Only implemented for numeric types
     fn as_single_ptr(&mut self) -> PolarsResult<usize> {
-        Err(PolarsError::InvalidOperation(
-            "operation 'as_single_ptr' not supported".into(),
-        ))
+        polars_bail!(opq = as_single_ptr, self._dtype());
     }
 
     /// Shift the values by a given period and fill the parts that will be empty due to this operation
@@ -467,15 +435,15 @@ pub trait SeriesTrait:
     /// If the [`DataType`] is one of `{Int8, UInt8, Int16, UInt16}` the `Series` is
     /// first cast to `Int64` to prevent overflow issues.
     fn _sum_as_series(&self) -> Series {
-        invalid_operation_panic!(self)
+        invalid_operation_panic!(_sum_as_series, self)
     }
     /// Get the max of the Series as a new Series of length 1.
     fn max_as_series(&self) -> Series {
-        invalid_operation_panic!(self)
+        invalid_operation_panic!(max_as_series, self)
     }
     /// Get the min of the Series as a new Series of length 1.
     fn min_as_series(&self) -> Series {
-        invalid_operation_panic!(self)
+        invalid_operation_panic!(min_as_series, self)
     }
     /// Get the median of the Series as a new Series of length 1.
     fn median_as_series(&self) -> Series {
@@ -504,55 +472,55 @@ pub trait SeriesTrait:
 
     /// Clone inner ChunkedArray and wrap in a new Arc
     fn clone_inner(&self) -> Arc<dyn SeriesTrait> {
-        invalid_operation_panic!(self)
+        invalid_operation_panic!(clone_inner, self)
     }
 
     #[cfg(feature = "object")]
     /// Get the value at this index as a downcastable Any trait ref.
     fn get_object(&self, _index: usize) -> Option<&dyn PolarsObjectSafe> {
-        invalid_operation_panic!(self)
+        invalid_operation_panic!(get_object, self)
     }
 
     /// Get a hold to self as `Any` trait reference.
     /// Only implemented for ObjectType
     fn as_any(&self) -> &dyn Any {
-        invalid_operation_panic!(self)
+        invalid_operation_panic!(as_any, self)
     }
 
     /// Get a hold to self as `Any` trait reference.
     /// Only implemented for ObjectType
     fn as_any_mut(&mut self) -> &mut dyn Any {
-        invalid_operation_panic!(self)
+        invalid_operation_panic!(as_any_mut, self)
     }
 
     /// Get a boolean mask of the local maximum peaks.
     fn peak_max(&self) -> BooleanChunked {
-        invalid_operation_panic!(self)
+        invalid_operation_panic!(peak_max, self)
     }
 
     /// Get a boolean mask of the local minimum peaks.
     fn peak_min(&self) -> BooleanChunked {
-        invalid_operation_panic!(self)
+        invalid_operation_panic!(peak_min, self)
     }
 
     /// Check if elements of this Series are in the right Series, or List values of the right Series.
     #[cfg(feature = "is_in")]
     fn is_in(&self, _other: &Series) -> PolarsResult<BooleanChunked> {
-        invalid_operation_panic!(self)
+        invalid_operation_panic!(is_in, self)
     }
     #[cfg(feature = "repeat_by")]
     fn repeat_by(&self, _by: &IdxCa) -> ListChunked {
-        invalid_operation_panic!(self)
+        invalid_operation_panic!(repeat_by, self)
     }
     #[cfg(feature = "checked_arithmetic")]
     fn checked_div(&self, _rhs: &Series) -> PolarsResult<Series> {
-        invalid_operation_panic!(self)
+        invalid_operation_panic!(checked_div, self)
     }
 
     #[cfg(feature = "mode")]
     /// Compute the most occurring element in the array.
     fn mode(&self) -> PolarsResult<Series> {
-        invalid_operation_panic!(self)
+        invalid_operation_panic!(mode, self);
     }
 
     #[cfg(feature = "rolling_window")]
@@ -563,7 +531,7 @@ pub trait SeriesTrait:
         _f: &dyn Fn(&Series) -> Series,
         _options: RollingOptionsFixedWindow,
     ) -> PolarsResult<Series> {
-        panic!("rolling apply not implemented for this dtype. Only implemented for numeric data.")
+        invalid_operation_panic!(rolling_apply, self);
     }
     #[cfg(feature = "concat_str")]
     /// Concat the values into a string array.
@@ -571,7 +539,7 @@ pub trait SeriesTrait:
     ///
     /// * `delimiter` - A string that will act as delimiter between values.
     fn str_concat(&self, _delimiter: &str) -> Utf8Chunked {
-        invalid_operation_panic!(self)
+        invalid_operation_panic!(str_concat, self);
     }
 }
 
@@ -580,12 +548,7 @@ impl<'a> (dyn SeriesTrait + 'a) {
     where
         N: PolarsDataType,
     {
-        if &N::get_dtype() == self.dtype() {
-            Ok(self.as_ref())
-        } else {
-            Err(PolarsError::SchemaMisMatch(
-                "cannot unpack Series; data types don't match".into(),
-            ))
-        }
+        polars_ensure!(&N::get_dtype() == self.dtype(), unpack);
+        Ok(self.as_ref())
     }
 }
