@@ -56,13 +56,18 @@ pub(crate) fn get_file_chunks(
     offsets
 }
 
-pub fn get_reader_bytes<R: Read + MmapBytesReader + ?Sized>(
-    reader: &mut R,
-) -> PolarsResult<ReaderBytes<'_>> {
+pub fn get_reader_bytes<'a, R: Read + MmapBytesReader + ?Sized>(
+    reader: &'a mut R,
+) -> PolarsResult<ReaderBytes<'a>> {
     // we have a file so we can mmap
     if let Some(file) = reader.to_file() {
         let mmap = unsafe { memmap::Mmap::map(file)? };
-        Ok(ReaderBytes::Mapped(mmap))
+
+        // somehow bck thinks borrows alias
+        // this is sound as file was already bound to 'a
+        use std::fs::File;
+        let file = unsafe { std::mem::transmute::<&File, &'a File>(file) };
+        Ok(ReaderBytes::Mapped(mmap, file))
     } else {
         // we can get the bytes for free
         if reader.to_bytes().is_some() {
@@ -151,13 +156,12 @@ pub(crate) fn parse_bytes_with_encoding(
     bytes: &[u8],
     encoding: CsvEncoding,
 ) -> PolarsResult<Cow<str>> {
-    let s = match encoding {
+    Ok(match encoding {
         CsvEncoding::Utf8 => simdutf8::basic::from_utf8(bytes)
-            .map_err(anyhow::Error::from)?
+            .map_err(|_| polars_err!(ComputeError: "invalid utf-8 sequence"))?
             .into(),
         CsvEncoding::LossyUtf8 => String::from_utf8_lossy(bytes),
-    };
-    Ok(s)
+    })
 }
 
 /// Infer the schema of a CSV file by reading through the first n records of the file,
@@ -194,9 +198,7 @@ pub fn infer_file_schema(
     let encoding = CsvEncoding::LossyUtf8;
 
     let bytes = skip_line_ending(skip_bom(reader_bytes), eol_char);
-    if bytes.is_empty() {
-        return Err(PolarsError::NoData("empty csv".into()));
-    }
+    polars_ensure!(!bytes.is_empty(), NoData: "empty CSV");
     let mut lines = SplitLines::new(bytes, quote_char.unwrap_or(b'"'), eol_char).skip(*skip_rows);
     // it can be that we have a single line without eol char
     let has_eol = bytes.contains(&eol_char);
@@ -297,7 +299,7 @@ pub fn infer_file_schema(
             try_parse_dates,
         );
     } else {
-        return Err(PolarsError::NoData("empty csv".into()));
+        polars_bail!(NoData: "empty CSV");
     };
     if !has_header {
         // re-init lines so that the header is included in type inference.
