@@ -40,14 +40,16 @@ pub trait ListNameSpaceExtension: IntoListNameSpace + Sized {
                         data_type: DataType::Categorical(_),
                         ..
                     } => {
-                        return Err(PolarsError::ComputeError(
-                            "Casting to 'Categorical' not allowed in 'arr.eval'".into(),
-                        ))
+                        polars_bail!(
+                            ComputeError: "casting to categorical not allowed in `arr.eval`"
+                        )
                     }
                     Expr::Column(name) => {
-                        if !name.is_empty() {
-                            return Err(PolarsError::ComputeError(r#"Named columns not allowed in 'arr.eval'. Consider using 'element' or 'col("")'."#.into()));
-                        }
+                        polars_ensure!(
+                            name.is_empty(),
+                            ComputeError:
+                            "named columns are not allowed in `arr.eval`; consider using `element` or `col(\"\")`"
+                        );
                     }
                     _ => {}
                 }
@@ -57,10 +59,10 @@ pub trait ListNameSpaceExtension: IntoListNameSpace + Sized {
             // ensure we get the new schema
             let output_field = eval_field_to_dtype(lst.ref_field(), &expr, true);
             if lst.is_empty() {
-                return Ok(Series::new_empty(s.name(), output_field.data_type()));
+                return Ok(Some(Series::new_empty(s.name(), output_field.data_type())));
             }
             if lst.null_count() == lst.len() {
-                return Ok(s);
+                return Ok(Some(s));
             }
 
             let phys_expr =
@@ -113,10 +115,10 @@ pub trait ListNameSpaceExtension: IntoListNameSpace + Sized {
             ca.rename(s.name());
 
             if ca.dtype() != output_field.data_type() {
-                ca.cast(output_field.data_type())
+                ca.cast(output_field.data_type()).map(Some)
             } else {
                 match err {
-                    None => Ok(ca.into_series()),
+                    None => Ok(Some(ca.into_series())),
                     Some(e) => Err(e),
                 }
             }
