@@ -48,21 +48,26 @@ fn to_physical_piped_expr(
 }
 
 fn is_streamable_sort(args: &SortArguments) -> bool {
-    let positive_slice = match args.slice {
+    // check if slice is positive
+    match args.slice {
         Some((offset, _)) => offset >= 0,
         None => true,
-    };
-    positive_slice && !args.nulls_last
+    }
 }
 
-fn is_streamable(node: Node, expr_arena: &Arena<AExpr>) -> bool {
+fn is_streamable(node: Node, expr_arena: &Arena<AExpr>, context: Context) -> bool {
     // check weather leaf colum is Col or Lit
     let mut seen_column = false;
     let mut seen_lit_range = false;
     let all = expr_arena.iter(node).all(|(_, ae)| match ae {
-        AExpr::Function { options, .. } | AExpr::AnonymousFunction { options, .. } => {
-            matches!(options.collect_groups, ApplyOptions::ApplyFlat)
-        }
+        AExpr::Function { options, .. } | AExpr::AnonymousFunction { options, .. } => match context
+        {
+            Context::Default => matches!(
+                options.collect_groups,
+                ApplyOptions::ApplyFlat | ApplyOptions::ApplyList
+            ),
+            Context::Aggregation => matches!(options.collect_groups, ApplyOptions::ApplyFlat),
+        },
         AExpr::Column(_) => {
             seen_column = true;
             true
@@ -89,10 +94,13 @@ fn is_streamable(node: Node, expr_arena: &Arena<AExpr>) -> bool {
     false
 }
 
-fn all_streamable(exprs: &[Node], expr_arena: &Arena<AExpr>) -> bool {
-    exprs.iter().all(|node| is_streamable(*node, expr_arena))
+fn all_streamable(exprs: &[Node], expr_arena: &Arena<AExpr>, context: Context) -> bool {
+    exprs
+        .iter()
+        .all(|node| is_streamable(*node, expr_arena, context))
 }
 
+/// check if all expressions are a simple column projection
 fn all_column(exprs: &[Node], expr_arena: &Arena<AExpr>) -> bool {
     exprs
         .iter()
@@ -169,12 +177,14 @@ pub(crate) fn insert_streaming_nodes(
     use ALogicalPlan::*;
     while let Some((root, mut state, mut current_idx)) = stack.pop() {
         match lp_arena.get(root) {
-            Selection { input, predicate } if is_streamable(*predicate, expr_arena) => {
+            Selection { input, predicate }
+                if is_streamable(*predicate, expr_arena, Context::Default) =>
+            {
                 state.streamable = true;
                 state.operators_sinks.push((!IS_SINK, !IS_RHS_JOIN, root));
                 stack.push((*input, state, current_idx))
             }
-            HStack { input, exprs, .. } if all_streamable(exprs, expr_arena) => {
+            HStack { input, exprs, .. } if all_streamable(exprs, expr_arena, Context::Default) => {
                 state.streamable = true;
                 state.operators_sinks.push((!IS_SINK, !IS_RHS_JOIN, root));
                 stack.push((*input, state, current_idx))
@@ -193,15 +203,14 @@ pub(crate) fn insert_streaming_nodes(
                 input,
                 by_column,
                 args,
-            } if is_streamable_sort(args)
-                && by_column.len() == 1
-                && all_column(by_column, expr_arena) =>
-            {
+            } if is_streamable_sort(args) && all_column(by_column, expr_arena) => {
                 state.streamable = true;
                 state.operators_sinks.push((IS_SINK, !IS_RHS_JOIN, root));
                 stack.push((*input, state, current_idx))
             }
-            Projection { input, expr, .. } if all_streamable(expr, expr_arena) => {
+            Projection { input, expr, .. }
+                if all_streamable(expr, expr_arena, Context::Default) =>
+            {
                 state.streamable = true;
                 state.operators_sinks.push((!IS_SINK, !IS_RHS_JOIN, root));
                 stack.push((*input, state, current_idx))
@@ -314,12 +323,21 @@ pub(crate) fn insert_streaming_nodes(
                     pipeline_trees[current_idx].push(state);
                 }
             }
+            Distinct { input, options }
+                if !options.maintain_order
+                    && !matches!(options.keep_strategy, UniqueKeepStrategy::None) =>
+            {
+                state.streamable = true;
+                state.operators_sinks.push((IS_SINK, !IS_RHS_JOIN, root));
+                stack.push((*input, state, current_idx))
+            }
             Aggregate {
                 input,
                 aggs,
                 maintain_order: false,
                 apply: None,
                 schema,
+                options,
                 ..
             } => {
                 #[cfg(feature = "dtype-categorical")]
@@ -327,6 +345,7 @@ pub(crate) fn insert_streaming_nodes(
                 #[cfg(not(feature = "dtype-categorical"))]
                 let string_cache = true;
 
+                #[allow(unused_variables)]
                 fn allowed_dtype(dt: &DataType, string_cache: bool) -> bool {
                     match dt {
                         #[cfg(feature = "object")]
@@ -337,12 +356,26 @@ pub(crate) fn insert_streaming_nodes(
                     }
                 }
                 let input_schema = lp_arena.get(*input).schema(lp_arena);
+                let mut can_stream = true;
 
-                if aggs.iter().all(|node| {
-                    polars_pipe::pipeline::can_convert_to_hash_agg(*node, expr_arena, &input_schema)
-                }) && schema
-                    .iter_dtypes()
-                    .all(|dt| allowed_dtype(dt, string_cache))
+                #[cfg(feature = "dynamic_groupby")]
+                {
+                    if options.rolling.is_some() || options.dynamic.is_some() {
+                        can_stream = false
+                    }
+                }
+
+                if can_stream
+                    && aggs.iter().all(|node| {
+                        polars_pipe::pipeline::can_convert_to_hash_agg(
+                            *node,
+                            expr_arena,
+                            &input_schema,
+                        )
+                    })
+                    && schema
+                        .iter_dtypes()
+                        .all(|dt| allowed_dtype(dt, string_cache))
                 {
                     state.streamable = true;
                     state.operators_sinks.push((IS_SINK, !IS_RHS_JOIN, root));
