@@ -1,5 +1,5 @@
 #![cfg_attr(docsrs, feature(doc_auto_cfg))]
-mod chunked_array;
+pub mod chunked_array;
 #[cfg(feature = "pivot")]
 pub use frame::pivot;
 mod frame;
