@@ -3,6 +3,7 @@ mod file_sink;
 pub(crate) mod groupby;
 mod joins;
 mod ordered;
+mod reproject;
 mod slice;
 mod sort;
 mod utils;
@@ -11,6 +12,7 @@ mod utils;
 pub(crate) use file_sink::*;
 pub(crate) use joins::*;
 pub(crate) use ordered::*;
+pub(crate) use reproject::*;
 pub(crate) use slice::*;
 pub(crate) use sort::*;
 
