@@ -1,7 +1,6 @@
 #[cfg(feature = "date_offset")]
 use polars_time::prelude::*;
 
-#[cfg(feature = "date_offset")]
 use super::*;
 
 #[cfg(feature = "date_offset")]
@@ -28,8 +27,19 @@ pub(super) fn date_offset(s: Series, offset: Duration) -> PolarsResult<Series> {
             ca.0.apply_mut(|v| adder(&offset, v));
             Ok(ca.into_series())
         }
-        dt => Err(PolarsError::ComputeError(
-            format!("cannot use 'date_offset' on Series of dtype: {dt:?}").into(),
-        )),
+        dt => polars_bail!(
+            ComputeError: "cannot use 'date_offset' on Series of datatype {}", dt,
+        ),
     }
 }
+
+pub(super) fn combine(s: &[Series], tu: TimeUnit) -> PolarsResult<Series> {
+    let date = &s[0];
+    let time = &s[1];
+
+    let date = date.cast(&DataType::Date)?;
+    let datetime = date.cast(&DataType::Datetime(tu, None)).unwrap();
+
+    let duration = time.cast(&DataType::Duration(tu))?;
+    Ok(datetime + duration)
+}
