@@ -5,7 +5,6 @@ use std::sync::Arc;
 
 #[cfg(feature = "parquet")]
 use polars_core::cloud::CloudOptions;
-use polars_core::frame::explode::MeltArgs;
 use polars_core::prelude::*;
 use polars_utils::arena::{Arena, Node};
 
@@ -17,7 +16,6 @@ use crate::logical_plan::CsvParserOptions;
 use crate::logical_plan::IpcScanOptionsInner;
 #[cfg(feature = "parquet")]
 use crate::logical_plan::ParquetOptions;
-use crate::logical_plan::{det_melt_schema, Context};
 use crate::prelude::*;
 use crate::utils::{aexprs_to_schema, PushNode};
 
@@ -36,11 +34,6 @@ pub enum ALogicalPlan {
         options: PythonOptions,
         predicate: Option<Node>,
     },
-    Melt {
-        input: Node,
-        args: Arc<MeltArgs>,
-        schema: SchemaRef,
-    },
     Slice {
         input: Node,
         offset: i64,
@@ -187,7 +180,6 @@ impl ALogicalPlan {
             AnonymousScan { .. } => "anonymous_scan",
             #[cfg(feature = "python")]
             PythonScan { .. } => "python_scan",
-            Melt { .. } => "melt",
             Slice { .. } => "slice",
             Selection { .. } => "selection",
             #[cfg(feature = "csv-file")]
@@ -259,7 +251,6 @@ impl ALogicalPlan {
                 return arena.get(*input).schema(arena)
             }
             Slice { input, .. } => return arena.get(*input).schema(arena),
-            Melt { schema, .. } => schema,
             MapFunction { input, function } => {
                 let input_schema = arena.get(*input).schema(arena);
 
@@ -295,11 +286,6 @@ impl ALogicalPlan {
                 inputs,
                 options: *options,
             },
-            Melt { args, schema, .. } => Melt {
-                input: inputs[0],
-                args: args.clone(),
-                schema: schema.clone(),
-            },
             Slice { offset, len, .. } => Slice {
                 input: inputs[0],
                 offset: *offset,
@@ -497,12 +483,7 @@ impl ALogicalPlan {
     pub fn copy_exprs(&self, container: &mut Vec<Node>) {
         use ALogicalPlan::*;
         match self {
-            Melt { .. }
-            | Slice { .. }
-            | Cache { .. }
-            | Distinct { .. }
-            | Union { .. }
-            | MapFunction { .. } => {}
+            Slice { .. } | Cache { .. } | Distinct { .. } | Union { .. } | MapFunction { .. } => {}
             Sort { by_column, .. } => container.extend_from_slice(by_column),
             Selection { predicate, .. } => container.push(*predicate),
             Projection { expr, .. } => container.extend_from_slice(expr),
@@ -574,7 +555,6 @@ impl ALogicalPlan {
                 }
                 return;
             }
-            Melt { input, .. } => *input,
             Slice { input, .. } => *input,
             Selection { input, .. } => *input,
             Projection { input, .. } => *input,
@@ -666,18 +646,6 @@ impl<'a> ALogicalPlanBuilder<'a> {
         }
     }
 
-    pub fn melt(self, args: Arc<MeltArgs>) -> Self {
-        let schema = det_melt_schema(&args, &self.schema());
-
-        let lp = ALogicalPlan::Melt {
-            input: self.root,
-            args,
-            schema,
-        };
-        let node = self.lp_arena.add(lp);
-        ALogicalPlanBuilder::new(node, self.expr_arena, self.lp_arena)
-    }
-
     pub fn project_local(self, exprs: Vec<Node>) -> Self {
         let input_schema = self.lp_arena.get(self.root).schema(self.lp_arena);
         let schema = aexprs_to_schema(&exprs, &input_schema, Context::Default, self.expr_arena);
