@@ -72,6 +72,10 @@ pub enum FunctionNode {
         columns: Arc<[Arc<str>]>,
         schema: SchemaRef,
     },
+    Melt {
+        args: Arc<MeltArgs>,
+        schema: SchemaRef,
+    },
 }
 
 impl PartialEq for FunctionNode {
@@ -95,6 +99,7 @@ impl PartialEq for FunctionNode {
             ) => existing_l == existing_r && new_l == new_r,
             (Drop { names: l }, Drop { names: r }) => l == r,
             (Explode { columns: l, .. }, Explode { columns: r, .. }) => l == r,
+            (Melt { args: l, .. }, Melt { args: r, .. }) => l == r,
             _ => false,
         }
     }
@@ -114,10 +119,22 @@ impl FunctionNode {
             | Rename { .. }
             | Explode { .. }
             | Drop { .. } => true,
+            Melt { args, .. } => args.streamable,
             Opaque { streamable, .. } => *streamable,
         }
     }
 
+    /// Whether this function will increase the number of rows
+    pub fn expands_rows(&self) -> bool {
+        use FunctionNode::*;
+        match self {
+            #[cfg(feature = "merge_sorted")]
+            MergeSorted { .. } => true,
+            Explode { .. } | Melt { .. } => true,
+            _ => false,
+        }
+    }
+
     pub(crate) fn schema<'a>(
         &self,
         input_schema: &'a SchemaRef,
@@ -137,9 +154,9 @@ impl FunctionNode {
                     .iter()
                     .map(|name| {
                         let name = name.as_ref();
-                        input_schema.get_field(name).ok_or_else(|| {
-                            PolarsError::SchemaFieldNotFound(name.to_string().into())
-                        })
+                        input_schema
+                            .get_field(name)
+                            .ok_or_else(|| polars_err!(SchemaFieldNotFound: "{}", name))
                     })
                     .collect::<PolarsResult<Schema>>()?;
                 Ok(Cow::Owned(Arc::new(schema)))
@@ -158,9 +175,9 @@ impl FunctionNode {
                                         .with_column(fld.name().clone(), fld.data_type().clone());
                                 }
                             } else {
-                                return Err(PolarsError::ComputeError(
-                                    format!("expected struct dtype, got: '{dtype:?}'").into(),
-                                ));
+                                polars_bail!(
+                                    SchemaMismatch: "expected struct dtype, got: `{}`", dtype
+                                );
                             }
                         } else {
                             new_schema.with_column(name.clone(), dtype.clone());
@@ -179,6 +196,7 @@ impl FunctionNode {
             Rename { existing, new, .. } => rename::rename_schema(input_schema, existing, new),
             Drop { names } => drop::drop_schema(input_schema, names),
             Explode { schema, .. } => Ok(Cow::Owned(schema.clone())),
+            Melt { schema, .. } => Ok(Cow::Owned(schema.clone())),
         }
     }
 
@@ -192,6 +210,7 @@ impl FunctionNode {
             | Unnest { .. }
             | Rename { .. }
             | Explode { .. }
+            | Melt { .. }
             | Drop { .. } => true,
             #[cfg(feature = "merge_sorted")]
             MergeSorted { .. } => true,
@@ -209,6 +228,7 @@ impl FunctionNode {
             | Unnest { .. }
             | Rename { .. }
             | Explode { .. }
+            | Melt { .. }
             | Drop { .. } => true,
             #[cfg(feature = "merge_sorted")]
             MergeSorted { .. } => true,
@@ -263,6 +283,10 @@ impl FunctionNode {
             Rename { existing, new, .. } => rename::rename_impl(df, existing, new),
             Drop { names } => drop::drop_impl(df, names),
             Explode { columns, .. } => df.explode(columns.as_ref()),
+            Melt { args, .. } => {
+                let args = (**args).clone();
+                df.melt2(args)
+            }
         }
     }
 }
@@ -309,6 +333,7 @@ impl Display for FunctionNode {
             Rename { .. } => write!(f, "RENAME"),
             Drop { .. } => write!(f, "DROP"),
             Explode { .. } => write!(f, "EXPLODE"),
+            Melt { .. } => write!(f, "MELT"),
         }
     }
 }
