@@ -42,7 +42,6 @@ pub use functions::*;
 pub use iterator::*;
 pub use lit::*;
 pub use optimizer::*;
-use polars_core::frame::explode::MeltArgs;
 pub use schema::*;
 #[cfg(feature = "serde")]
 use serde::{Deserialize, Serialize};
@@ -98,9 +97,11 @@ impl ErrorStateSync {
                 };
                 err
             }
-            ErrorState::AlreadyEncountered { prev_err_msg } => PolarsError::ComputeError(
-                format!("LogicalPlan already failed with error: `{prev_err_msg}`").into(),
-            ),
+            ErrorState::AlreadyEncountered { prev_err_msg } => {
+                polars_err!(
+                    ComputeError: "LogicalPlan already failed with error: '{}'", prev_err_msg,
+                )
+            }
         }
     }
 }
@@ -226,12 +227,6 @@ pub enum LogicalPlan {
         offset: i64,
         len: IdxSize,
     },
-    /// A Melt operation
-    Melt {
-        input: Box<LogicalPlan>,
-        args: Arc<MeltArgs>,
-        schema: SchemaRef,
-    },
     /// A (User Defined) Function
     MapFunction {
         input: Box<LogicalPlan>,
@@ -308,7 +303,6 @@ impl LogicalPlan {
             HStack { schema, .. } => Ok(Cow::Borrowed(schema)),
             Distinct { input, .. } | FileSink { input, .. } => input.schema(),
             Slice { input, .. } => input.schema(),
-            Melt { schema, .. } => Ok(Cow::Borrowed(schema)),
             MapFunction {
                 input, function, ..
             } => {
