@@ -19,6 +19,7 @@ pub struct DatetimeInfer<T> {
     pub logical_type: DataType,
 }
 
+#[cfg(feature = "dtype-datetime")]
 impl TryFrom<Pattern> for DatetimeInfer<i64> {
     type Error = PolarsError;
 
@@ -40,9 +41,7 @@ impl TryFrom<Pattern> for DatetimeInfer<i64> {
                 fmt_len: 0,
                 logical_type: DataType::Datetime(TimeUnit::Microseconds, None),
             }),
-            _ => Err(PolarsError::ComputeError(
-                "could not convert pattern".into(),
-            )),
+            _ => polars_bail!(ComputeError: "could not convert pattern"),
         }
     }
 }
@@ -69,9 +68,7 @@ impl TryFrom<Pattern> for DatetimeInfer<i32> {
                 fmt_len: 0,
                 logical_type: DataType::Date,
             }),
-            _ => Err(PolarsError::ComputeError(
-                "could not convert pattern".into(),
-            )),
+            _ => polars_bail!(ComputeError: "could not convert pattern"),
         }
     }
 }
@@ -155,7 +152,8 @@ fn transform_date_bytes(val: &[u8], fmt: &[u8], fmt_len: u16) -> Option<i32> {
     unsafe { strptime::parse(val, fmt, fmt_len).map(|ndt| naive_date_to_date(ndt.date())) }
 }
 
-fn transform_datetime_ns(val: &str, fmt: &str) -> Option<i64> {
+#[cfg(feature = "dtype-datetime")]
+pub(crate) fn transform_datetime_ns(val: &str, fmt: &str) -> Option<i64> {
     let out = NaiveDateTime::parse_from_str(val, fmt)
         .ok()
         .map(datetime_to_timestamp_ns);
@@ -166,7 +164,8 @@ fn transform_datetime_ns(val: &str, fmt: &str) -> Option<i64> {
     })
 }
 
-fn transform_datetime_us(val: &str, fmt: &str) -> Option<i64> {
+#[cfg(feature = "dtype-datetime")]
+pub(crate) fn transform_datetime_us(val: &str, fmt: &str) -> Option<i64> {
     let out = NaiveDateTime::parse_from_str(val, fmt)
         .ok()
         .map(datetime_to_timestamp_us);
@@ -181,7 +180,8 @@ fn transform_datetime_us_bytes(val: &[u8], fmt: &[u8], fmt_len: u16) -> Option<i
     unsafe { strptime::parse(val, fmt, fmt_len).map(datetime_to_timestamp_us) }
 }
 
-fn transform_datetime_ms(val: &str, fmt: &str) -> Option<i64> {
+#[cfg(feature = "dtype-datetime")]
+pub(crate) fn transform_datetime_ms(val: &str, fmt: &str) -> Option<i64> {
     let out = NaiveDateTime::parse_from_str(val, fmt)
         .ok()
         .map(datetime_to_timestamp_ms);
@@ -242,12 +242,7 @@ pub(crate) fn to_datetime(
             let pattern = subset
                 .into_iter()
                 .find_map(|opt_val| opt_val.and_then(infer_pattern_datetime_single))
-                .ok_or_else(|| {
-                    PolarsError::ComputeError(
-                        "Could not find an appropriate format to parse dates, please define a fmt"
-                            .into(),
-                    )
-                })?;
+                .ok_or_else(|| polars_err!(parse_fmt_idk = "date"))?;
             let mut infer = DatetimeInfer::<i64>::try_from(pattern).unwrap();
             match tu {
                 TimeUnit::Nanoseconds => infer.transform = transform_datetime_ns,
@@ -275,12 +270,7 @@ pub(crate) fn to_date(ca: &Utf8Chunked) -> PolarsResult<DateChunked> {
             let pattern = subset
                 .into_iter()
                 .find_map(|opt_val| opt_val.and_then(infer_pattern_date_single))
-                .ok_or_else(|| {
-                    PolarsError::ComputeError(
-                        "Could not find an appropriate format to parse dates, please define a fmt"
-                            .into(),
-                    )
-                })?;
+                .ok_or_else(|| polars_err!(parse_fmt_idk = "date"))?;
             let mut infer = DatetimeInfer::<i32>::try_from(pattern).unwrap();
             infer.coerce_utf8(ca).date().cloned()
         }
