@@ -50,10 +50,17 @@ pub(super) fn compile_fmt(fmt: &str) -> String {
 // # Safety
 // Caller must ensure that fmt adheres to the fmt rules of chrono and `fmt_len` is correct.
 pub(super) unsafe fn parse(val: &[u8], fmt: &[u8], fmt_len: u16) -> Option<NaiveDateTime> {
-    const ESCAPE: u8 = b'%';
-    if val.len() < fmt_len as usize {
+    let mut offset = 0;
+    let mut negative = false;
+    if val.starts_with(b"-") && fmt.starts_with(b"%Y") {
+        offset = 1;
+        negative = true;
+    }
+    if val.len() - offset != (fmt_len as usize) {
         return None;
     }
+
+    const ESCAPE: u8 = b'%';
     let mut year: i32 = 1;
     // minimal day/month is always 1
     // otherwise chrono may panic.
@@ -66,14 +73,6 @@ pub(super) unsafe fn parse(val: &[u8], fmt: &[u8], fmt_len: u16) -> Option<Naive
 
     let mut fmt_iter = fmt.iter();
 
-    let mut offset = 0;
-    let mut negative = false;
-
-    if val.starts_with(b"-") && fmt.starts_with(b"%Y") {
-        offset = 1;
-        negative = true;
-    }
-
     while let Some(fmt_b) = fmt_iter.next() {
         debug_assert!(offset < val.len());
         let b = *val.get_unchecked(offset);
@@ -127,8 +126,6 @@ pub(super) unsafe fn parse(val: &[u8], fmt: &[u8], fmt_len: u16) -> Option<Naive
                     nano *= 1_000_000;
                     break;
                 }
-                // utc can be ignored
-                b'Z' => {}
                 _ => return None,
             }
         }
@@ -165,7 +162,6 @@ pub(super) fn fmt_len(fmt: &[u8]) -> Option<u16> {
                 b'H' => cnt += 2,
                 b'M' => cnt += 2,
                 b'S' => cnt += 2,
-                b'Z' => cnt += 1,
                 b'9' => {
                     cnt += 9;
                     debug_assert_eq!(iter.next(), Some(&b'f'));
@@ -202,37 +198,67 @@ mod test {
                 "2021-01-01",
                 "%Y-%m-%d",
                 10,
-                Some(NaiveDate::from_ymd(2021, 1, 1).and_hms_nano(0, 0, 0, 0)),
+                Some(
+                    NaiveDate::from_ymd_opt(2021, 1, 1)
+                        .unwrap()
+                        .and_hms_nano_opt(0, 0, 0, 0)
+                        .unwrap(),
+                ),
             ),
             (
                 "2021-01-01 07:45:12",
                 "%Y-%m-%d %H:%M:%S",
                 19,
-                Some(NaiveDate::from_ymd(2021, 1, 1).and_hms_nano(7, 45, 12, 0)),
+                Some(
+                    NaiveDate::from_ymd_opt(2021, 1, 1)
+                        .unwrap()
+                        .and_hms_nano_opt(7, 45, 12, 0)
+                        .unwrap(),
+                ),
             ),
             (
                 "2021-01-01 07:45:12",
                 "%Y-%m-%d %H:%M:%S",
                 19,
-                Some(NaiveDate::from_ymd(2021, 1, 1).and_hms_nano(7, 45, 12, 0)),
+                Some(
+                    NaiveDate::from_ymd_opt(2021, 1, 1)
+                        .unwrap()
+                        .and_hms_nano_opt(7, 45, 12, 0)
+                        .unwrap(),
+                ),
             ),
             (
                 "2019-04-18T02:45:55.555000000",
                 "%Y-%m-%dT%H:%M:%S.%9f",
                 29,
-                Some(NaiveDate::from_ymd(2019, 4, 18).and_hms_nano(2, 45, 55, 555000000)),
+                Some(
+                    NaiveDate::from_ymd_opt(2019, 4, 18)
+                        .unwrap()
+                        .and_hms_nano_opt(2, 45, 55, 555000000)
+                        .unwrap(),
+                ),
             ),
             (
                 "2019-04-18T02:45:55.555000",
                 "%Y-%m-%dT%H:%M:%S.%6f",
                 26,
-                Some(NaiveDate::from_ymd(2019, 4, 18).and_hms_nano(2, 45, 55, 555000000)),
+                Some(
+                    NaiveDate::from_ymd_opt(2019, 4, 18)
+                        .unwrap()
+                        .and_hms_nano_opt(2, 45, 55, 555000000)
+                        .unwrap(),
+                ),
             ),
             (
                 "2019-04-18T02:45:55.555",
                 "%Y-%m-%dT%H:%M:%S.%3f",
                 23,
-                Some(NaiveDate::from_ymd(2019, 4, 18).and_hms_nano(2, 45, 55, 555000000)),
+                Some(
+                    NaiveDate::from_ymd_opt(2019, 4, 18)
+                        .unwrap()
+                        .and_hms_nano_opt(2, 45, 55, 555000000)
+                        .unwrap(),
+                ),
             ),
         ];
 
