@@ -5,6 +5,7 @@ use polars_core::prelude::*;
 use polars_core::POOL;
 #[cfg(feature = "serde")]
 use serde::{Deserialize, Serialize};
+use smartstring::alias::String as SmartString;
 
 use crate::prelude::*;
 
@@ -15,7 +16,7 @@ struct Wrap<T>(pub T);
 #[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
 pub struct DynamicGroupOptions {
     /// Time or index column
-    pub index_column: String,
+    pub index_column: SmartString,
     /// start a window at this interval
     pub every: Duration,
     /// window duration
@@ -33,7 +34,7 @@ pub struct DynamicGroupOptions {
 impl Default for DynamicGroupOptions {
     fn default() -> Self {
         Self {
-            index_column: "".to_string(),
+            index_column: "".into(),
             every: Duration::new(1),
             period: Duration::new(1),
             offset: Duration::new(1),
@@ -49,7 +50,7 @@ impl Default for DynamicGroupOptions {
 #[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
 pub struct RollingGroupOptions {
     /// Time or index column
-    pub index_column: String,
+    pub index_column: SmartString,
     /// window duration
     pub period: Duration,
     pub offset: Duration,
@@ -127,14 +128,11 @@ impl Wrap<&DataFrame> {
                 let out = out.cast(&Int64).unwrap();
                 return Ok((out, by, gt));
             }
-            dt => {
-                return Err(PolarsError::ComputeError(
-                    format!(
-                    "expected any of the following dtypes {{Date, Datetime, Int32, Int64}}, got {dt}",
-                )
-                    .into(),
-                ))
-            }
+            dt => polars_bail!(
+                ComputeError:
+                "expected any of the following dtypes: {{ Date, Datetime, Int32, Int64 }}, got {}",
+                dt
+            ),
         };
         self.impl_groupby_rolling(dt, by, options, tu, time_type)
     }
@@ -194,14 +192,11 @@ impl Wrap<&DataFrame> {
                 }
                 return Ok((out, keys, gt));
             }
-            dt => {
-                return Err(PolarsError::ComputeError(
-                    format!(
-                    "expected any of the following dtypes {{Date, Datetime, Int32, Int64}}, got {dt}",
-                )
-                    .into(),
-                ))
-            }
+            dt => polars_bail!(
+                ComputeError:
+                "expected any of the following dtypes: {{ Date, Datetime, Int32, Int64 }}, got {}",
+                dt
+            ),
         };
         self.impl_groupby_dynamic(dt, by, options, tu, time_type)
     }
@@ -221,6 +216,11 @@ impl Wrap<&DataFrame> {
         let w = Window::new(options.every, options.period, options.offset);
         let dt = dt.datetime().unwrap();
         let tz = dt.time_zone();
+        let dt = match tz {
+            #[cfg(feature = "timezones")]
+            Some(_) => dt.replace_time_zone(None)?,
+            _ => dt.clone(),
+        };
 
         let mut lower_bound = None;
         let mut upper_bound = None;
@@ -389,7 +389,7 @@ impl Wrap<&DataFrame> {
             }
         };
 
-        let dt = unsafe { dt.clone().into_series().agg_first(&groups) };
+        let dt = unsafe { dt.into_series().agg_first(&groups) };
         let mut dt = dt.datetime().unwrap().as_ref().clone();
         for key in by.iter_mut() {
             *key = unsafe { key.agg_first(&groups) };
@@ -405,17 +405,43 @@ impl Wrap<&DataFrame> {
 
         if let (true, Some(lower), Some(higher)) = (options.include_boundaries, lower, upper_bound)
         {
-            by.push(lower.into_datetime(tu, tz.clone()).into_series());
-            let s = Int64Chunked::new_vec(UP_NAME, higher)
-                .into_datetime(tu, tz.clone())
-                .into_series();
+            match tz {
+                #[cfg(feature = "timezones")]
+                Some(tz) => by.push(
+                    lower
+                        .into_datetime(tu, None)
+                        .replace_time_zone(Some(tz))?
+                        .into_series(),
+                ),
+                _ => by.push(lower.into_datetime(tu, None).into_series()),
+            };
+            let s = match tz {
+                #[cfg(feature = "timezones")]
+                Some(tz) => Int64Chunked::new_vec(UP_NAME, higher)
+                    .into_datetime(tu, None)
+                    .replace_time_zone(Some(tz))?
+                    .into_series(),
+                _ => Int64Chunked::new_vec(UP_NAME, higher)
+                    .into_datetime(tu, None)
+                    .into_series(),
+            };
             by.push(s);
         }
 
-        dt.into_datetime(tu, None)
-            .into_series()
-            .cast(time_type)
-            .map(|s| (s, by, groups))
+        match tz {
+            #[cfg(feature = "timezones")]
+            Some(tz) => dt
+                .into_datetime(tu, None)
+                .replace_time_zone(Some(tz))?
+                .into_series()
+                .cast(time_type)
+                .map(|s| (s, by, groups)),
+            _ => dt
+                .into_datetime(tu, None)
+                .into_series()
+                .cast(time_type)
+                .map(|s| (s, by, groups)),
+        }
     }
 
     /// Returns: time_keys, keys, groupsproxy
