@@ -130,9 +130,7 @@ pub trait TemporalMethods: AsSeries {
             DataType::Datetime(_, _) => s.datetime().map(|ca| ca.hour()),
             #[cfg(feature = "dtype-time")]
             DataType::Time => s.time().map(|ca| ca.hour()),
-            _ => Err(PolarsError::InvalidOperation(
-                format!("operation not supported on dtype {:?}", s.dtype()).into(),
-            )),
+            dt => polars_bail!(opq = hour, dt),
         }
     }
 
@@ -145,9 +143,7 @@ pub trait TemporalMethods: AsSeries {
             DataType::Datetime(_, _) => s.datetime().map(|ca| ca.minute()),
             #[cfg(feature = "dtype-time")]
             DataType::Time => s.time().map(|ca| ca.minute()),
-            _ => Err(PolarsError::InvalidOperation(
-                format!("operation not supported on dtype {:?}", s.dtype()).into(),
-            )),
+            dt => polars_bail!(opq = minute, dt),
         }
     }
 
@@ -160,9 +156,7 @@ pub trait TemporalMethods: AsSeries {
             DataType::Datetime(_, _) => s.datetime().map(|ca| ca.second()),
             #[cfg(feature = "dtype-time")]
             DataType::Time => s.time().map(|ca| ca.second()),
-            _ => Err(PolarsError::InvalidOperation(
-                format!("operation not supported on dtype {:?}", s.dtype()).into(),
-            )),
+            dt => polars_bail!(opq = second, dt),
         }
     }
 
@@ -175,9 +169,7 @@ pub trait TemporalMethods: AsSeries {
             DataType::Datetime(_, _) => s.datetime().map(|ca| ca.nanosecond()),
             #[cfg(feature = "dtype-time")]
             DataType::Time => s.time().map(|ca| ca.nanosecond()),
-            _ => Err(PolarsError::InvalidOperation(
-                format!("operation not supported on dtype {:?}", s.dtype()).into(),
-            )),
+            dt => polars_bail!(opq = nanosecond, dt),
         }
     }
 
@@ -192,9 +184,7 @@ pub trait TemporalMethods: AsSeries {
             DataType::Date => s.date().map(|ca| ca.day()),
             #[cfg(feature = "dtype-datetime")]
             DataType::Datetime(_, _) => s.datetime().map(|ca| ca.day()),
-            _ => Err(PolarsError::InvalidOperation(
-                format!("operation not supported on dtype {:?}", s.dtype()).into(),
-            )),
+            dt => polars_bail!(opq = day, dt),
         }
     }
     /// Returns the weekday number where monday = 0 and sunday = 6
@@ -205,9 +195,7 @@ pub trait TemporalMethods: AsSeries {
             DataType::Date => s.date().map(|ca| ca.weekday()),
             #[cfg(feature = "dtype-datetime")]
             DataType::Datetime(_, _) => s.datetime().map(|ca| ca.weekday()),
-            _ => Err(PolarsError::InvalidOperation(
-                format!("operation not supported on dtype {:?}", s.dtype()).into(),
-            )),
+            dt => polars_bail!(opq = weekday, dt),
         }
     }
 
@@ -220,9 +208,7 @@ pub trait TemporalMethods: AsSeries {
             DataType::Date => s.date().map(|ca| ca.week()),
             #[cfg(feature = "dtype-datetime")]
             DataType::Datetime(_, _) => s.datetime().map(|ca| ca.week()),
-            _ => Err(PolarsError::InvalidOperation(
-                format!("operation not supported on dtype {:?}", s.dtype()).into(),
-            )),
+            dt => polars_bail!(opq = week, dt),
         }
     }
 
@@ -236,9 +222,7 @@ pub trait TemporalMethods: AsSeries {
             DataType::Date => s.date().map(|ca| ca.ordinal()),
             #[cfg(feature = "dtype-datetime")]
             DataType::Datetime(_, _) => s.datetime().map(|ca| ca.ordinal()),
-            _ => Err(PolarsError::InvalidOperation(
-                format!("operation not supported on dtype {:?}", s.dtype()).into(),
-            )),
+            dt => polars_bail!(opq = ordinal_day, dt),
         }
     }
 
@@ -251,9 +235,7 @@ pub trait TemporalMethods: AsSeries {
             DataType::Date => s.date().map(|ca| ca.year()),
             #[cfg(feature = "dtype-datetime")]
             DataType::Datetime(_, _) => s.datetime().map(|ca| ca.year()),
-            _ => Err(PolarsError::InvalidOperation(
-                format!("operation not supported on dtype {:?}", s.dtype()).into(),
-            )),
+            dt => polars_bail!(opq = year, dt),
         }
     }
 
@@ -264,9 +246,7 @@ pub trait TemporalMethods: AsSeries {
             DataType::Date => s.date().map(|ca| ca.iso_year()),
             #[cfg(feature = "dtype-datetime")]
             DataType::Datetime(_, _) => s.datetime().map(|ca| ca.iso_year()),
-            _ => Err(PolarsError::InvalidOperation(
-                format!("operation not supported on dtype {:?}", s.dtype()).into(),
-            )),
+            dt => polars_bail!(opq = iso_year, dt),
         }
     }
 
@@ -279,9 +259,7 @@ pub trait TemporalMethods: AsSeries {
             DataType::Date => s.date().map(|ca| ca.year()),
             #[cfg(feature = "dtype-datetime")]
             DataType::Datetime(_, _) => s.datetime().map(|ca| ca.year()),
-            _ => Err(PolarsError::InvalidOperation(
-                format!("operation not supported on dtype {:?}", s.dtype()).into(),
-            )),
+            dt => polars_bail!(opq = ordinal_year, dt),
         }
     }
 
@@ -294,9 +272,7 @@ pub trait TemporalMethods: AsSeries {
             DataType::Date => s.date().map(|ca| ca.quarter()),
             #[cfg(feature = "dtype-datetime")]
             DataType::Datetime(_, _) => s.datetime().map(|ca| ca.quarter()),
-            _ => Err(PolarsError::InvalidOperation(
-                format!("operation not supported on dtype {:?}", s.dtype()).into(),
-            )),
+            dt => polars_bail!(opq = quarter, dt),
         }
     }
 
@@ -311,9 +287,7 @@ pub trait TemporalMethods: AsSeries {
             DataType::Date => s.date().map(|ca| ca.month()),
             #[cfg(feature = "dtype-datetime")]
             DataType::Datetime(_, _) => s.datetime().map(|ca| ca.month()),
-            _ => Err(PolarsError::InvalidOperation(
-                format!("operation not supported on dtype {:?}", s.dtype()).into(),
-            )),
+            dt => polars_bail!(opq = month, dt),
         }
     }
 
@@ -329,9 +303,7 @@ pub trait TemporalMethods: AsSeries {
             }
             #[cfg(feature = "dtype-time")]
             DataType::Time => s.time().map(|ca| ca.strftime(fmt).into_series()),
-            _ => Err(PolarsError::InvalidOperation(
-                format!("operation not supported on dtype {:?}", s.dtype()).into(),
-            )),
+            dt => polars_bail!(opq = strftime, dt),
         }
     }
 
@@ -340,9 +312,7 @@ pub trait TemporalMethods: AsSeries {
     fn timestamp(&self, tu: TimeUnit) -> PolarsResult<Int64Chunked> {
         let s = self.as_series();
         if matches!(s.dtype(), DataType::Time) {
-            Err(PolarsError::ComputeError(
-                "Cannot compute timestamp of a series with dtype 'Time'".into(),
-            ))
+            polars_bail!(opq = timestamp, s.dtype());
         } else {
             s.cast(&DataType::Datetime(tu, None))
                 .map(|s| s.datetime().unwrap().deref().clone())
