@@ -2,16 +2,17 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING, Any, Mapping, Sequence, overload
 
-from polars.datatypes import N_INFER_DEFAULT, SchemaDefinition, SchemaDict
+from polars.datatypes import N_INFER_DEFAULT
 from polars.dependencies import _PYARROW_AVAILABLE
-from polars.dependencies import numpy as np
 from polars.dependencies import pandas as pd
 from polars.dependencies import pyarrow as pa
+from polars.exceptions import NoDataError
 from polars.internals import DataFrame, Series
-from polars.internals.construction import _unpack_schema, include_unknowns
-from polars.utils import deprecated_alias
+from polars.utils.decorators import deprecate_nonkeyword_arguments, deprecated_alias
 
 if TYPE_CHECKING:
+    from polars.datatypes import SchemaDefinition, SchemaDict
+    from polars.dependencies import numpy as np
     from polars.internals.type_aliases import Orientation
 
 
@@ -65,13 +66,13 @@ def from_dict(
     └─────┴─────┘
 
     """
-    return DataFrame._from_dict(
-        data=data, schema=schema, schema_overrides=schema_overrides
-    )
+    return DataFrame._from_dict(data, schema=schema, schema_overrides=schema_overrides)
 
 
+@deprecate_nonkeyword_arguments(allowed_args=["data", "schema"])
+@deprecated_alias(dicts="data")
 def from_dicts(
-    dicts: Sequence[dict[str, Any]],
+    data: Sequence[dict[str, Any]],
     infer_schema_length: int | None = N_INFER_DEFAULT,
     *,
     schema: SchemaDefinition | None = None,
@@ -82,7 +83,7 @@ def from_dicts(
 
     Parameters
     ----------
-    dicts
+    data
         Sequence with dictionaries mapping column name to value
     infer_schema_length
         How many dictionaries/rows to scan to determine the data types
@@ -161,22 +162,21 @@ def from_dicts(
     └─────┴─────┴──────┴──────┘
 
     """
-    column_names, schema = _unpack_schema(
-        schema, schema_overrides=schema_overrides, include_overrides_in_columns=True
-    )
-    schema = include_unknowns(schema, column_names or list(schema))
-    return DataFrame._from_dicts(
-        dicts,
-        infer_schema_length,
-        schema=(column_names and schema),
+    if not data and not (schema or schema_overrides):
+        raise NoDataError("No rows. Cannot infer schema.")
+
+    return DataFrame(
+        data,
+        schema=schema,
         schema_overrides=schema_overrides,
+        infer_schema_length=infer_schema_length,
     )
 
 
 @deprecated_alias(columns="schema")
 def from_records(
     data: Sequence[Sequence[Any]],
-    schema: Sequence[str] | None = None,
+    schema: SchemaDefinition | None = None,
     *,
     schema_overrides: SchemaDict | None = None,
     orient: Orientation | None = None,
@@ -304,10 +304,11 @@ def from_numpy(
     )
 
 
+@deprecate_nonkeyword_arguments(allowed_args=["data", "schema"])
 def from_arrow(
-    a: pa.Table | pa.Array | pa.ChunkedArray,
+    data: pa.Table | pa.Array | pa.ChunkedArray,
     rechunk: bool = True,
-    schema: Sequence[str] | None = None,
+    schema: SchemaDefinition | None = None,
     schema_overrides: SchemaDict | None = None,
 ) -> DataFrame | Series:
     """
@@ -318,14 +319,10 @@ def from_arrow(
 
     Parameters
     ----------
-    a : :class:`pyarrow.Table` or :class:`pyarrow.Array`
+    data : :class:`pyarrow.Table` or :class:`pyarrow.Array`
         Data representing an Arrow Table or Array.
     rechunk : bool, default True
         Make sure that all data is in contiguous memory.
-    schema : Sequence of str, dict, default None
-        Column labels to use for resulting DataFrame. Must match data dimensions.
-        If not specified, existing Array table columns are used, with missing names
-        named as `column_0`, `column_1`, etc.
     schema : Sequence of str, (str,DataType) pairs, or a {str:DataType,} dict
         The DataFrame schema may be declared in several ways:
 
@@ -378,42 +375,49 @@ def from_arrow(
     ]
 
     """
-    if isinstance(a, pa.Table):
+    if isinstance(data, pa.Table):
         return DataFrame._from_arrow(
-            a, rechunk=rechunk, schema=schema, schema_overrides=schema_overrides
+            data, rechunk=rechunk, schema=schema, schema_overrides=schema_overrides
         )
-    elif isinstance(a, (pa.Array, pa.ChunkedArray)):
-        return Series._from_arrow("", a, rechunk)
+    elif isinstance(data, (pa.Array, pa.ChunkedArray)):
+        return Series._from_arrow("", data, rechunk)
     else:
-        raise ValueError(f"Expected Arrow Table or Array, got {type(a)}.")
+        raise ValueError(f"expected Arrow Table or Array, got {type(data)}.")
 
 
 @overload
 def from_pandas(
-    df: pd.DataFrame,
-    rechunk: bool = True,
-    nan_to_null: bool = True,
-    schema_overrides: SchemaDict | None = None,
+    data: pd.DataFrame,
+    rechunk: bool = ...,
+    nan_to_null: bool = ...,
+    schema_overrides: SchemaDict | None = ...,
+    *,
+    include_index: bool = ...,
 ) -> DataFrame:
     ...
 
 
 @overload
 def from_pandas(
-    df: pd.Series | pd.DatetimeIndex,
-    rechunk: bool = True,
-    nan_to_null: bool = True,
-    schema_overrides: SchemaDict | None = None,
+    data: pd.Series | pd.DatetimeIndex,
+    rechunk: bool = ...,
+    nan_to_null: bool = ...,
+    schema_overrides: SchemaDict | None = ...,
+    *,
+    include_index: bool = ...,
 ) -> Series:
     ...
 
 
-@deprecated_alias(nan_to_none="nan_to_null")
+@deprecate_nonkeyword_arguments()
+@deprecated_alias(nan_to_none="nan_to_null", df="data")
 def from_pandas(
-    df: pd.DataFrame | pd.Series | pd.DatetimeIndex,
+    data: pd.DataFrame | pd.Series | pd.DatetimeIndex,
     rechunk: bool = True,
     nan_to_null: bool = True,
     schema_overrides: SchemaDict | None = None,
+    *,
+    include_index: bool = False,
 ) -> DataFrame | Series:
     """
     Construct a Polars DataFrame or Series from a pandas DataFrame or Series.
@@ -424,7 +428,7 @@ def from_pandas(
 
     Parameters
     ----------
-    df: :class:`pandas.DataFrame`, :class:`pandas.Series`, :class:`pandas.DatetimeIndex`
+    data: :class:`pandas.DataFrame`, :class:`pandas.Series`, :class:`pandas.DatetimeIndex`
         Data represented as a pandas DataFrame, Series, or DatetimeIndex.
     rechunk : bool, default True
         Make sure that all data is in contiguous memory.
@@ -432,6 +436,8 @@ def from_pandas(
         If data contains `NaN` values PyArrow will convert the ``NaN`` to ``None``
     schema_overrides : dict, default None
         Support override of inferred types for one or more columns.
+    include_index : bool, default False
+        Load any non-default pandas indexes as columns.
 
     Returns
     -------
@@ -469,20 +475,22 @@ def from_pandas(
         3
     ]
 
-    """
-    if isinstance(df, (pd.Series, pd.DatetimeIndex)):
-        return Series._from_pandas("", df, nan_to_null=nan_to_null)
-    elif isinstance(df, pd.DataFrame):
+    """  # noqa: W505
+    if isinstance(data, (pd.Series, pd.DatetimeIndex)):
+        return Series._from_pandas("", data, nan_to_null=nan_to_null)
+    elif isinstance(data, pd.DataFrame):
         return DataFrame._from_pandas(
-            df,
+            data,
             rechunk=rechunk,
             nan_to_null=nan_to_null,
             schema_overrides=schema_overrides,
+            include_index=include_index,
         )
     else:
-        raise ValueError(f"Expected pandas DataFrame or Series, got {type(df)}.")
+        raise ValueError(f"Expected pandas DataFrame or Series, got {type(data)}.")
 
 
+@deprecate_nonkeyword_arguments()
 def from_dataframe(df: Any, allow_copy: bool = True) -> DataFrame:
     """
     Build a Polars DataFrame from any dataframe supporting the interchange protocol.
@@ -502,7 +510,7 @@ def from_dataframe(df: Any, allow_copy: bool = True) -> DataFrame:
     https://data-apis.org/dataframe-protocol/latest/index.html
 
     Zero-copy conversions currently cannot be guaranteed and will throw a
-    ``NotImplementedError``.
+    ``RuntimeError``.
 
     Using a dedicated function like :func:`from_pandas` or :func:`from_arrow` is a more
     efficient method of conversion.
@@ -520,11 +528,8 @@ def from_dataframe(df: Any, allow_copy: bool = True) -> DataFrame:
             "pyarrow>=11.0.0 is required for converting a dataframe interchange object"
             " to a Polars dataframe."
         )
-    if not allow_copy:
-        raise NotImplementedError(
-            "Polars cannot guarantee zero-copy conversion from dataframe interchange"
-            " objects at this time."
-        )
+
+    import pyarrow.interchange  # noqa: F401
 
     pa_table = pa.interchange.from_dataframe(df, allow_copy=allow_copy)
     return from_arrow(pa_table, rechunk=allow_copy)  # type: ignore[return-value]
