@@ -38,7 +38,7 @@ from polars.datatypes import (
     py_type_to_arrow_type,
     py_type_to_dtype,
 )
-from polars.datatypes_constructor import (
+from polars.datatypes.constructor import (
     numpy_type_to_constructor,
     numpy_values_and_dtype,
     polars_type_to_constructor,
@@ -54,13 +54,9 @@ from polars.dependencies import numpy as np
 from polars.dependencies import pandas as pd
 from polars.dependencies import pyarrow as pa
 from polars.exceptions import ShapeError
-from polars.utils import (
-    _is_generator,
-    arrlen,
-    deprecated_alias,
-    range_to_series,
-    threadpool_size,
-)
+from polars.utils.decorators import deprecated_alias
+from polars.utils.meta import threadpool_size
+from polars.utils.various import _is_generator, arrlen, range_to_series
 
 with contextlib.suppress(ImportError):  # Module not available when building docs
     from polars.polars import PyDataFrame, PySeries
@@ -77,7 +73,7 @@ if version_info >= (3, 10):
 else:
 
     def dataclass_type_hints(obj: type) -> dict[str, Any]:
-        return obj.__annotations__
+        return getattr(obj, "__annotations__", {})
 
 
 def is_namedtuple(value: Any, annotated: bool = False) -> bool:
@@ -437,8 +433,8 @@ def sequence_to_pyseries(
             while True:
                 try:
                     return constructor(name, values, strict)
-                except TypeError as error:
-                    str_val = str(error)
+                except TypeError as exc:
+                    str_val = str(exc)
 
                     # from x to float
                     # error message can be:
@@ -465,7 +461,7 @@ def sequence_to_pyseries(
                         constructor = py_type_to_constructor(PyDecimal)
 
                     else:
-                        raise error
+                        raise exc
 
 
 @deprecated_alias(nan_to_none="nan_to_null")
