@@ -6,9 +6,10 @@ from functools import wraps
 from typing import TYPE_CHECKING, Any, Callable, TypeVar
 
 import polars.internals as pli
-from polars.datatypes import PolarsDataType, dtype_to_ffiname
+from polars.datatypes import dtype_to_ffiname
 
 if TYPE_CHECKING:
+    from polars.datatypes import PolarsDataType
     from polars.polars import PySeries
 
     if sys.version_info >= (3, 10):
@@ -25,7 +26,7 @@ class _EmptyBytecodeHelper:
     def __init__(self) -> None:
         # generate bytecode for empty functions with/without a docstring
         def _empty_with_docstring() -> None:
-            """"""
+            """"""  # noqa: D419
 
         def _empty_without_docstring() -> None:
             pass
@@ -54,7 +55,7 @@ def _is_empty_method(func: SeriesMethod) -> bool:
     fc = func.__code__
     return (fc.co_code in _EMPTY_BYTECODE) and (
         (len(fc.co_consts) == 2 and fc.co_consts[1] is None)
-        # account for potentially optimized-out docstrings
+        # account for optimized-out docstrings (eg: running 'python -OO')
         or (sys.flags.optimize == 2 and fc.co_consts == (None,))
     )
 
@@ -74,7 +75,7 @@ def _expr_lookup(namespace: str | None) -> set[tuple[str | None, str, tuple[str,
         if not name.startswith("_"):
             try:
                 m = getattr(expr, name)
-            except AttributeError:  # May be raised for @property methods
+            except AttributeError:  # may raise for @property methods
                 continue
             if callable(m):
                 # add function signature (argument names only) to the lookup
