@@ -505,16 +505,16 @@ def test_struct_schema_on_append_extend_3452() -> None:
     with pytest.raises(
         pl.SchemaError,
         match=(
-            "cannot append field with name: address to struct with field name: city,"
-            " please check your schema"
+            'cannot append field with name "address" '
+            'to struct with field name "city"'
         ),
     ):
         housing1.append(housing2, append_chunks=True)
     with pytest.raises(
         pl.SchemaError,
         match=(
-            "cannot extend field with name: address to struct with field name: city,"
-            " please check your schema"
+            'cannot extend field with name "address" '
+            'to struct with field name "city"'
         ),
     ):
         housing1.append(housing2, append_chunks=False)
@@ -860,3 +860,21 @@ def test_struct_applies_as_map() -> None:
     ).to_dict(False) == {
         "x": [{"x": "a", "y": "dd"}, {"x": "b", "y": "ee"}, {"x": "c", "y": "ff"}]
     }
+
+
+def test_struct_with_lit() -> None:
+    expr = pl.struct([pl.col("a"), pl.lit(1).alias("b")])
+
+    assert (
+        pl.DataFrame({"a": pl.Series([], dtype=pl.Int64)}).select(expr).to_dict(False)
+    ) == {"a": []}
+
+    assert (
+        pl.DataFrame({"a": pl.Series([1], dtype=pl.Int64)}).select(expr).to_dict(False)
+    ) == {"a": [{"a": 1, "b": 1}]}
+
+    assert (
+        pl.DataFrame({"a": pl.Series([1, 2], dtype=pl.Int64)})
+        .select(expr)
+        .to_dict(False)
+    ) == {"a": [{"a": 1, "b": 1}, {"a": 2, "b": 1}]}
