@@ -5,6 +5,7 @@ import io
 import sys
 import tempfile
 import textwrap
+import typing
 import zlib
 from datetime import date, datetime, time, timedelta, timezone
 from pathlib import Path
@@ -14,14 +15,13 @@ import numpy as np
 import pytest
 
 import polars as pl
-from polars import DataType
 from polars.exceptions import ComputeError, NoDataError
 from polars.testing import (
     assert_frame_equal,
     assert_frame_equal_local_categoricals,
     assert_series_equal,
 )
-from polars.utils import normalise_filepath
+from polars.utils.various import normalise_filepath
 
 if TYPE_CHECKING:
     from polars.internals.type_aliases import TimeUnit
@@ -60,6 +60,7 @@ def test_to_from_buffer(df_no_lists: pl.DataFrame) -> None:
         assert_frame_equal_local_categoricals(df.select(["time", "cat"]), read_df)
 
 
+@pytest.mark.write_disk()
 def test_to_from_file(df_no_lists: pl.DataFrame) -> None:
     df = df_no_lists.drop("strings_nulls")
 
@@ -366,6 +367,7 @@ def test_read_csv_buffer_ownership() -> None:
     assert buf.read() == bts
 
 
+@pytest.mark.write_disk()
 def test_read_csv_encoding() -> None:
     bts = (
         b"Value1,Value2,Value3,Value4,Region\n"
@@ -574,7 +576,7 @@ def test_ignore_try_parse_dates() -> None:
     ).encode()
 
     headers = ["a", "b", "c"]
-    dtypes: dict[str, type[DataType]] = {
+    dtypes: dict[str, type[pl.DataType]] = {
         k: pl.Utf8 for k in headers
     }  # Forces Utf8 type for every column
     df = pl.read_csv(csv, columns=headers, dtypes=dtypes)
@@ -748,6 +750,7 @@ def test_csv_string_escaping() -> None:
     assert_frame_equal(df_read, df)
 
 
+@pytest.mark.write_disk()
 def test_glob_csv(df_no_lists: pl.DataFrame) -> None:
     df = df_no_lists.drop("strings_nulls")
     with tempfile.TemporaryDirectory() as temp_dir:
@@ -877,10 +880,10 @@ def test_invalid_datetime_format() -> None:
     tz_naive = pl.Series(["2020-01-01T00:00:00"]).str.strptime(pl.Datetime)
     tz_aware = tz_naive.dt.replace_time_zone("UTC")
     with pytest.raises(
-        ComputeError, match="Cannot format NaiveDateTime with format '%q'."
+        ComputeError, match="cannot format NaiveDateTime with format '%q'"
     ):
         tz_naive.to_frame().write_csv(datetime_format="%q")
-    with pytest.raises(ComputeError, match="Cannot format DateTime with format '%q'."):
+    with pytest.raises(ComputeError, match="cannot format DateTime with format '%q'"):
         tz_aware.to_frame().write_csv(datetime_format="%q")
 
 
@@ -1029,7 +1032,7 @@ def test_error_message() -> None:
     data = io.StringIO("target,wind,energy,miso\n" "1,2,3,4\n" "1,2,1e5,1\n")
     with pytest.raises(
         ComputeError,
-        match=r"Could not parse `1e5` as dtype Int64 at column 'energy' \(column number 3\)",
+        match=r"Could not parse `1e5` as dtype `i64` at column 'energy' \(column number 3\)",
     ):
         pl.read_csv(data, infer_schema_length=1)
 
@@ -1066,6 +1069,7 @@ def test_csv_categorical_categorical_merge() -> None:
     ].to_list() == ["A", "B"]
 
 
+@typing.no_type_check
 def test_batched_csv_reader(foods_file_path: Path) -> None:
     reader = pl.read_csv_batched(foods_file_path, batch_size=4)
     batches = reader.next_batches(5)
@@ -1073,21 +1077,32 @@ def test_batched_csv_reader(foods_file_path: Path) -> None:
     assert batches is not None
     assert len(batches) == 5
     assert batches[0].to_dict(False) == {
-        "category": ["vegetables"],
-        "calories": [45],
-        "fats_g": [0.5],
-        "sugars_g": [2],
+        "category": ["vegetables", "seafood", "meat", "fruit", "seafood", "meat"],
+        "calories": [45, 150, 100, 60, 140, 120],
+        "fats_g": [0.5, 5.0, 5.0, 0.0, 5.0, 10.0],
+        "sugars_g": [2, 0, 0, 11, 1, 1],
     }
     assert batches[-1].to_dict(False) == {
-        "category": ["meat"],
-        "calories": [120],
-        "fats_g": [10.0],
-        "sugars_g": [1],
+        "category": ["fruit", "meat", "vegetables", "fruit"],
+        "calories": [130, 100, 30, 50],
+        "fats_g": [0.0, 7.0, 0.0, 0.0],
+        "sugars_g": [25, 0, 5, 11],
     }
+    assert_frame_equal(pl.concat(batches), pl.read_csv(foods_file_path))
+    # the final batch of the low-memory variant is different
+    reader = pl.read_csv_batched(foods_file_path, batch_size=4, low_memory=True)
+    batches = reader.next_batches(5)
+    assert len(batches) == 5
+    batches += reader.next_batches(5)
+    assert_frame_equal(pl.concat(batches), pl.read_csv(foods_file_path))
+
+    reader = pl.read_csv_batched(foods_file_path, batch_size=4, low_memory=True)
+    batches = reader.next_batches(10)
+    assert_frame_equal(pl.concat(batches), pl.read_csv(foods_file_path))
 
 
 def test_batched_csv_reader_all_batches(foods_file_path: Path) -> None:
-    for new_columns in [None, ["Category", "Calories", "Fats_g", "Augars_g"]]:
+    for new_columns in [None, ["Category", "Calories", "Fats_g", "Sugars_g"]]:
         out = pl.read_csv(foods_file_path, new_columns=new_columns)
         reader = pl.read_csv_batched(
             foods_file_path, new_columns=new_columns, batch_size=4
@@ -1172,6 +1187,7 @@ def test_csv_statistics_offset() -> None:
     assert pl.read_csv(io.StringIO(csv), n_rows=N).height == 4999
 
 
+@pytest.mark.write_disk()
 @pytest.mark.xfail(sys.platform == "win32", reason="Does not work on Windows")
 def test_csv_scan_categorical() -> None:
     N = 5_000
