@@ -52,6 +52,7 @@ def test_row_count(foods_parquet_path: Path) -> None:
     assert df["foo"].to_list() == [10, 16, 21, 23, 24, 30, 35]
 
 
+@pytest.mark.write_disk()
 def test_categorical_parquet_statistics() -> None:
     df = pl.DataFrame(
         {
@@ -89,6 +90,7 @@ def test_categorical_parquet_statistics() -> None:
         assert df.shape == (4, 3)
 
 
+@pytest.mark.write_disk()
 def test_null_parquet() -> None:
     df = pl.DataFrame([pl.Series("foo", [], dtype=pl.Int8)])
     with tempfile.TemporaryDirectory() as temp_dir:
@@ -98,6 +100,68 @@ def test_null_parquet() -> None:
     assert_frame_equal(out, df)
 
 
+@pytest.mark.write_disk()
+def test_parquet_eq_stats() -> None:
+    with tempfile.TemporaryDirectory() as temp_dir:
+        file_path = Path(temp_dir) / "stats.parquet"
+
+        df1 = pd.DataFrame({"a": [None, 1, None, 2, 3, 3, 4, 4, 5, 5]})
+        df1.to_parquet(file_path, engine="pyarrow")
+        df = pl.scan_parquet(file_path).filter(pl.col("a") == 4).collect()
+        assert df["a"].to_list() == [4.0, 4.0]
+
+        assert (
+            pl.scan_parquet(file_path)
+            .filter(pl.col("a") == 2)
+            .select(pl.col("a").sum())
+        ).collect()[0, "a"] == 2.0
+
+        assert pl.scan_parquet(file_path).filter(pl.col("a") == 5).collect().shape == (
+            2,
+            1,
+        )
+
+
+@pytest.mark.write_disk()
+def test_parquet_is_in_stats() -> None:
+    with tempfile.TemporaryDirectory() as temp_dir:
+        file_path = Path(temp_dir) / "stats.parquet"
+
+        df1 = pd.DataFrame({"a": [None, 1, None, 2, 3, 3, 4, 4, 5, 5]})
+        df1.to_parquet(file_path, engine="pyarrow")
+        df = pl.scan_parquet(file_path).filter(pl.col("a").is_in([5])).collect()
+        assert df["a"].to_list() == [5.0, 5.0]
+
+        assert (
+            pl.scan_parquet(file_path)
+            .filter(pl.col("a").is_in([5]))
+            .select(pl.col("a").sum())
+        ).collect()[0, "a"] == 10.0
+
+        assert (
+            pl.scan_parquet(file_path)
+            .filter(pl.col("a").is_in([1, 2, 3]))
+            .select(pl.col("a").sum())
+        ).collect()[0, "a"] == 9.0
+
+        assert (
+            pl.scan_parquet(file_path)
+            .filter(pl.col("a").is_in([1, 2, 3]))
+            .select(pl.col("a").sum())
+        ).collect()[0, "a"] == 9.0
+
+        assert (
+            pl.scan_parquet(file_path)
+            .filter(pl.col("a").is_in([5]))
+            .select(pl.col("a").sum())
+        ).collect()[0, "a"] == 10.0
+
+        assert pl.scan_parquet(file_path).filter(
+            pl.col("a").is_in([1, 2, 3, 4, 5])
+        ).collect().shape == (8, 1)
+
+
+@pytest.mark.write_disk()
 def test_parquet_stats() -> None:
     with tempfile.TemporaryDirectory() as temp_dir:
         file_path = Path(temp_dir) / "binary_stats.parquet"
@@ -139,6 +203,80 @@ def test_row_count_schema(parquet_file_path: Path) -> None:
     ).dtypes == [pl.UInt32, pl.Utf8]
 
 
+@pytest.mark.write_disk()
+def test_parquet_eq_statistics(monkeypatch: Any, capfd: Any) -> None:
+    monkeypatch.setenv("POLARS_VERBOSE", "1")
+
+    df = pl.DataFrame({"idx": pl.arange(100, 200, eager=True)}).with_columns(
+        (pl.col("idx") // 25).alias("part")
+    )
+    df = pl.concat(df.partition_by("part", as_dict=False), rechunk=False)
+    assert df.n_chunks("all") == [4, 4]
+
+    with tempfile.TemporaryDirectory() as temp_dir:
+        file_path = Path(temp_dir) / "stats.parquet"
+        df.write_parquet(file_path, statistics=True, use_pyarrow=False)
+
+    with tempfile.TemporaryDirectory() as temp_dir:
+        file_path = Path(temp_dir) / "stats.parquet"
+        df.write_parquet(file_path, statistics=True, use_pyarrow=False)
+
+        for pred in [
+            pl.col("idx") == 50,
+            pl.col("idx") == 150,
+            pl.col("idx") == 210,
+        ]:
+            result = pl.scan_parquet(file_path).filter(pred).collect()
+            assert_frame_equal(result, df.filter(pred))
+
+    captured = capfd.readouterr().err
+    assert (
+        "parquet file must be read, statistics not sufficient for predicate."
+        in captured
+    )
+    assert (
+        "parquet file can be skipped, the statistics were sufficient"
+        " to apply the predicate." in captured
+    )
+
+
+@pytest.mark.write_disk()
+def test_parquet_is_in_statistics(monkeypatch: Any, capfd: Any) -> None:
+    monkeypatch.setenv("POLARS_VERBOSE", "1")
+
+    df = pl.DataFrame({"idx": pl.arange(0, 100, eager=True)}).with_columns(
+        (pl.col("idx") // 25).alias("part")
+    )
+    df = pl.concat(df.partition_by("part", as_dict=False), rechunk=False)
+    assert df.n_chunks("all") == [4, 4]
+
+    with tempfile.TemporaryDirectory() as temp_dir:
+        file_path = Path(temp_dir) / "stats.parquet"
+        df.write_parquet(file_path, statistics=True, use_pyarrow=False)
+
+    with tempfile.TemporaryDirectory() as temp_dir:
+        file_path = Path(temp_dir) / "stats.parquet"
+        df.write_parquet(file_path, statistics=True, use_pyarrow=False)
+
+        for pred in [
+            pl.col("idx").is_in([150, 200, 300]),
+            pl.col("idx").is_in([5, 250, 350]),
+        ]:
+            result = pl.scan_parquet(file_path).filter(pred).collect()
+            assert_frame_equal(result, df.filter(pred))
+
+    captured = capfd.readouterr().err
+    assert (
+        "parquet file must be read, statistics not sufficient for predicate."
+        in captured
+    )
+    assert (
+        "parquet file can be skipped, the statistics were sufficient"
+        " to apply the predicate." in captured
+    )
+
+
+@pytest.mark.write_disk()
 def test_parquet_statistics(monkeypatch: Any, capfd: Any) -> None:
     monkeypatch.setenv("POLARS_VERBOSE", "1")
 
@@ -174,6 +312,7 @@ def test_parquet_statistics(monkeypatch: Any, capfd: Any) -> None:
 
 
 @pytest.mark.xfail(sys.platform == "win32", reason="Does not work on Windows")
+@pytest.mark.write_disk()
 def test_streaming_categorical() -> None:
     df = pl.DataFrame(
         [
@@ -201,6 +340,7 @@ def test_streaming_categorical() -> None:
 
 
 @pytest.mark.xfail(sys.platform == "win32", reason="Does not work on Windows")
+@pytest.mark.write_disk()
 def test_parquet_struct_categorical() -> None:
     df = pl.DataFrame(
         [
