@@ -311,3 +311,31 @@ def test_tree_validation_streaming() -> None:
 
     out = df_1.join(df_3, on="a", how="left")
     assert out.collect(streaming=True).shape == (3, 3)
+
+
+def test_streaming_apply(monkeypatch: Any, capfd: Any) -> None:
+    monkeypatch.setenv("POLARS_VERBOSE", "1")
+    q = pl.DataFrame({"a": [1, 2]}).lazy()
+
+    (
+        q.select(pl.col("a").apply(lambda x: x * 2, return_dtype=pl.Int64)).collect(
+            streaming=True
+        )
+    )
+    (_, err) = capfd.readouterr()
+    assert "df -> projection -> ordered_sink" in err
+
+
+def test_streaming_unique(monkeypatch: Any, capfd: Any) -> None:
+    monkeypatch.setenv("POLARS_VERBOSE", "1")
+    df = pl.DataFrame({"a": [1, 2, 2, 2], "b": [3, 4, 4, 4], "c": [5, 6, 7, 7]})
+    q = df.lazy().unique(subset=["a", "c"], maintain_order=False).sort(["a", "b", "c"])
+    assert_frame_equal(q.collect(streaming=True), q.collect(streaming=False))
+
+    q = df.lazy().unique(subset=["b", "c"], maintain_order=False).sort(["a", "b", "c"])
+    assert_frame_equal(q.collect(streaming=True), q.collect(streaming=False))
+
+    q = df.lazy().unique(subset=None, maintain_order=False).sort(["a", "b", "c"])
+    assert_frame_equal(q.collect(streaming=True), q.collect(streaming=False))
+    (_, err) = capfd.readouterr()
+    assert "df -> re-project-sink -> sort_multiple" in err
